@@ -51,9 +51,6 @@
 #include <libgnome/gnome-macros.h>
 
 #include "gnome-calc.h"
-#include "sr.h"
-
-#undef GNOME_CALC_DEBUG
 
 typedef void (*sighandler_t)(int);
 
@@ -160,7 +157,7 @@ gnome_calc_class_init (GnomeCalcClass *class)
 	class->result_changed = NULL;
 }
 
-#ifdef GNOME_CALC_DEBUG 
+#if 0 /*only used for debugging*/
 static void
 dump_stack(GnomeCalc *gc)
 {
@@ -211,29 +208,12 @@ stack_pop(GList **stack)
 	g_free(s);
 }
 
-static void
-set_display (GnomeCalc *gc)
-{
-	GtkWidget *label = gc->_priv->text_display;
-	gchar *string;
-
-	string = g_strconcat ("<span foreground=\"white\"  font_desc=\"Helvetica 24\">", gc->_priv->result_string, "</span>", NULL);
-	gtk_label_set_markup (GTK_LABEL (label), string);
-	g_free (string);
-}
-
 static void
 do_error(GnomeCalc *gc)
 {
 	gc->_priv->error = TRUE;
-	if (errno == ERANGE)
-		strcpy(gc->_priv->result_string,_("inf"));
-	else
-		strcpy(gc->_priv->result_string,"e");
-
-	set_display (gc);
-
-
+	strcpy(gc->_priv->result_string,"e");
+	gtk_entry_set_text (GTK_ENTRY (gc->_priv->text_display), gc->_priv->result_string);
 }
 
 /*we handle sigfpe's so that we can find all the errors*/
@@ -301,9 +281,8 @@ reduce_stack(GnomeCalc *gc)
 
 	if(errno>0 ||
 	   finite(stack->d.number)==0) {
-	   	do_error(gc);
-		stack->d.number = 0;
-		errno = 0;		
+		errno = 0;
+		do_error(gc);
 	}
 }
 
@@ -404,7 +383,7 @@ set_result(GnomeCalc *gc)
 		return;
 
 	gc->_priv->result = stack->d.number;
-	
+
         /* make sure put values in a consistent manner */
 	/* XXX: perhaps we can make sure the calculator works on all locales,
 	 * but currently it will lose precision if we don't do this */
@@ -419,7 +398,8 @@ set_result(GnomeCalc *gc)
 	strncpy(gc->_priv->result_string,buf,12);
 	gc->_priv->result_string[12]='\0';
 
-	set_display (gc);
+	gtk_entry_set_text (GTK_ENTRY(gc->_priv->text_display), gc->_priv->result_string);
+
 	gtk_signal_emit(GTK_OBJECT(gc),
 			gnome_calc_signals[RESULT_CHANGED_SIGNAL],
 			gc->_priv->result);
@@ -462,30 +442,15 @@ convert_num(gdouble num, GnomeCalcMode from, GnomeCalcMode to)
 {
 	if(to==from)
 		return num;
-	else if(from==GNOME_CALC_DEG) {
-		if(to==GNOME_CALC_RAD) {
-			if (fabs (num - 90) < 0.000001)
-				return M_PI_2;
-			else if (fabs (num - 180) < 0.000001)
-				return M_PI;
-			else if (fabs (num - 45) < 0.000001)
-				return M_PI_4;
-			else if (fabs (num - 360) < 0.000001)
-				return 2*M_PI;
+	else if(from==GNOME_CALC_DEG)
+		if(to==GNOME_CALC_RAD)
 			return (num*M_PI)/180;
-		} else /*GRAD*/
+		else /*GRAD*/
 			return (num*200)/180;
-	}
 	else if(from==GNOME_CALC_RAD)
-		if(to==GNOME_CALC_DEG) {
-			if (num == M_PI)
-				return 180;
-			else if (num == M_PI_2)
-				return 90;
-			else if (num == M_PI_4)
-				return 45;
+		if(to==GNOME_CALC_DEG)
 			return (num*180)/M_PI;
-		} else /*GRAD*/
+		else /*GRAD*/
 			return (num*200)/M_PI;
 	else /*GRAD*/
 		if(to==GNOME_CALC_DEG)
@@ -497,7 +462,7 @@ convert_num(gdouble num, GnomeCalcMode from, GnomeCalcMode to)
 static void
 no_func(GtkWidget *w, gpointer data)
 {
-	GnomeCalc *gc = g_object_get_data(G_OBJECT(w), "set_data");
+	GnomeCalc *gc = gtk_object_get_user_data(GTK_OBJECT(w));
 
 	g_return_if_fail(gc!=NULL);
 
@@ -513,11 +478,7 @@ no_func(GtkWidget *w, gpointer data)
 	}
 
 	reduce_stack_prec(gc,NULL);
-
-	if(gc->_priv->error) {
-		gc->_priv->error = FALSE;
-		return;
-	}
+	if(gc->_priv->error) return;
 	set_result(gc);
 
 	unselect_invert(gc);
@@ -526,7 +487,7 @@ no_func(GtkWidget *w, gpointer data)
 static void
 simple_func(GtkWidget *w, gpointer data)
 {
-	GnomeCalc *gc = g_object_get_data(G_OBJECT(w), "set_data");
+	GnomeCalc *gc = gtk_object_get_user_data(GTK_OBJECT(w));
 	CalculatorStack *stack;
 	CalculatorButton *but = data;
 	MathFunction1 func = but->data;
@@ -550,13 +511,13 @@ simple_func(GtkWidget *w, gpointer data)
 		unselect_invert(gc);
 		return;
 	}
-	
+
 	/*only convert non inverting functions*/
 	if(!gc->_priv->invert && but->convert_to_rad)
 		stack->d.number = convert_num(stack->d.number,
 					      gc->_priv->mode,
 					      GNOME_CALC_RAD);
-	
+
 	errno = 0;
 	{
 		sighandler_t old = signal(SIGFPE,sigfpe_handler);
@@ -566,22 +527,20 @@ simple_func(GtkWidget *w, gpointer data)
 			stack->d.number = (*invfunc)(stack->d.number);
 		signal(SIGFPE,old);
 	}
-	
+
 	if(errno>0 ||
 	   finite(stack->d.number)==0) {
-	   	do_error(gc);
-		gc->_priv->error = FALSE;
-		stack->d.number = 0;
 		errno = 0;
+		do_error(gc);
 		return;
 	}
-	
+
 	/*we are converting back from rad to mode*/
 	if(gc->_priv->invert && but->convert_to_rad)
 		stack->d.number = convert_num(stack->d.number,
 					      GNOME_CALC_RAD,
 					      gc->_priv->mode);
-	
+
 	set_result(gc);
 
 	unselect_invert(gc);
@@ -590,7 +549,7 @@ simple_func(GtkWidget *w, gpointer data)
 static void
 math_func(GtkWidget *w, gpointer data)
 {
-	GnomeCalc *gc = g_object_get_data(G_OBJECT(w), "set_data");
+	GnomeCalc *gc = gtk_object_get_user_data(GTK_OBJECT(w));
 	CalculatorStack *stack;
 	CalculatorButton *but = data;
 	MathFunction2 func = but->data;
@@ -636,7 +595,7 @@ reset_calc(GtkWidget *w, gpointer data)
 {
 	GnomeCalc *gc;
 	if(w)
-		gc = g_object_get_data(G_OBJECT(w), "set_data");
+		gc = gtk_object_get_user_data(GTK_OBJECT(w));
 	else
 		gc = data;
 
@@ -663,7 +622,7 @@ reset_calc(GtkWidget *w, gpointer data)
 static void
 clear_calc(GtkWidget *w, gpointer data)
 {
-	GnomeCalc *gc = g_object_get_data(G_OBJECT(w), "set_data");
+	GnomeCalc *gc = gtk_object_get_user_data(GTK_OBJECT(w));
 
 	g_return_if_fail(gc!=NULL);
 
@@ -709,7 +668,7 @@ gnome_calc_clear(GnomeCalc *gc, const gboolean reset)
 static void
 add_digit (GtkWidget *w, gpointer data)
 {
-	GnomeCalc *gc = g_object_get_data (G_OBJECT (w), "set_data");
+	GnomeCalc *gc = gtk_object_get_user_data (GTK_OBJECT (w));
 	CalculatorButton *but = data;
 	gchar *digit = but->name;
 
@@ -759,8 +718,8 @@ add_digit (GtkWidget *w, gpointer data)
 
 	strcat (gc->_priv->result_string, digit);
 
-	set_display (gc);
- 	
+	gtk_entry_set_text (GTK_ENTRY (gc->_priv->text_display), gc->_priv->result_string);
+
         /* make sure get values in a consistent manner */
 	gnome_i18n_push_c_numeric_locale ();
 	sscanf(gc->_priv->result_string, "%lf", &gc->_priv->result);
@@ -777,7 +736,7 @@ c_neg(gdouble arg)
 static void
 negate_val(GtkWidget *w, gpointer data)
 {
-	GnomeCalc *gc = g_object_get_data(G_OBJECT(w), "set_data");
+	GnomeCalc *gc = gtk_object_get_user_data(GTK_OBJECT(w));
 	char *p;
 
 	g_return_if_fail(gc!=NULL);
@@ -799,8 +758,7 @@ negate_val(GtkWidget *w, gpointer data)
 		else
 			*p='-';
 	} else {
-		if(gc->_priv->result_string[0]=='-' || 
-		   gc->_priv->result == 0)
+		if(gc->_priv->result_string[0]=='-')
 			gc->_priv->result_string[0]=' ';
 		else
 			gc->_priv->result_string[0]='-';
@@ -810,8 +768,8 @@ negate_val(GtkWidget *w, gpointer data)
 	gnome_i18n_pop_c_numeric_locale ();
 	sscanf(gc->_priv->result_string, "%lf", &gc->_priv->result);
 	gnome_i18n_push_c_numeric_locale ();
-
-	set_display (gc);
+	
+	gtk_entry_set_text (GTK_ENTRY (gc->_priv->text_display), gc->_priv->result_string);
 }
 
 static gdouble
@@ -902,8 +860,8 @@ gnome_calc_set(GnomeCalc *gc, gdouble result)
 static void
 store_m(GtkWidget *w, gpointer data)
 {
-	GnomeCalc *gc = g_object_get_data(G_OBJECT(w), "set_data");
-	
+	GnomeCalc *gc = gtk_object_get_user_data(GTK_OBJECT(w));
+
 	g_return_if_fail(gc!=NULL);
 
 	if(gc->_priv->error)
@@ -913,15 +871,15 @@ store_m(GtkWidget *w, gpointer data)
 
 	gc->_priv->memory = gc->_priv->result;
 
-	set_display (gc);
- 	
+	gtk_entry_set_text (GTK_ENTRY (gc->_priv->text_display), gc->_priv->result_string);
+
 	unselect_invert(gc);
 }
 
 static void
 recall_m(GtkWidget *w, gpointer data)
 {
-	GnomeCalc *gc = g_object_get_data(G_OBJECT(w), "set_data");
+	GnomeCalc *gc = gtk_object_get_user_data(GTK_OBJECT(w));
 
 	g_return_if_fail(gc!=NULL);
 
@@ -936,8 +894,8 @@ recall_m(GtkWidget *w, gpointer data)
 static void
 sum_m(GtkWidget *w, gpointer data)
 {
-	GnomeCalc *gc = g_object_get_data(G_OBJECT(w), "set_data");
-	
+	GnomeCalc *gc = gtk_object_get_user_data(GTK_OBJECT(w));
+
 	g_return_if_fail(gc!=NULL);
 
 	if(gc->_priv->error)
@@ -947,15 +905,15 @@ sum_m(GtkWidget *w, gpointer data)
 
 	gc->_priv->memory += gc->_priv->result;
 
-	set_display (gc);
- 	
+	gtk_entry_set_text (GTK_ENTRY (gc->_priv->text_display), gc->_priv->result_string);
+
 	unselect_invert(gc);
 }
 
 static void
 exchange_m(GtkWidget *w, gpointer data)
 {
-	GnomeCalc *gc = g_object_get_data(G_OBJECT(w), "set_data");
+	GnomeCalc *gc = gtk_object_get_user_data(GTK_OBJECT(w));
 
 	g_return_if_fail(gc!=NULL);
 
@@ -970,7 +928,7 @@ exchange_m(GtkWidget *w, gpointer data)
 static void
 invert_toggle(GtkWidget *w, gpointer data)
 {
-	GnomeCalc *gc = g_object_get_data(G_OBJECT(w), "set_data");
+	GnomeCalc *gc = gtk_object_get_user_data(GTK_OBJECT(w));
 
 	g_return_if_fail(gc!=NULL);
 
@@ -986,7 +944,7 @@ invert_toggle(GtkWidget *w, gpointer data)
 static void
 drg_toggle(GtkWidget *w, gpointer data)
 {
-	GnomeCalc *gc = g_object_get_data(G_OBJECT(w), "set_data");
+	GnomeCalc *gc = gtk_object_get_user_data(GTK_OBJECT(w));
 	GnomeCalcMode oldmode;
 
 	g_return_if_fail(gc!=NULL);
@@ -1021,7 +979,7 @@ drg_toggle(GtkWidget *w, gpointer data)
 static void
 set_pi(GtkWidget *w, gpointer data)
 {
-	GnomeCalc *gc = g_object_get_data(G_OBJECT(w), "set_data");
+	GnomeCalc *gc = gtk_object_get_user_data(GTK_OBJECT(w));
 
 	g_return_if_fail(gc!=NULL);
 
@@ -1034,14 +992,11 @@ set_pi(GtkWidget *w, gpointer data)
 }
 
 static void
-set_e(GtkWidget *w, GdkEvent *event, gpointer data)
+set_e(GtkWidget *w, gpointer data)
 {
-	GnomeCalc *gc = g_object_get_data(G_OBJECT(w), "set_data");
+	GnomeCalc *gc = gtk_object_get_user_data(GTK_OBJECT(w));
 
 	g_return_if_fail(gc!=NULL);
-	
-	if (event->type == GDK_3BUTTON_PRESS)
-		run_slide_rule ();
 
 	if(gc->_priv->error)
 		return;
@@ -1054,7 +1009,7 @@ set_e(GtkWidget *w, GdkEvent *event, gpointer data)
 static void
 add_parenth(GtkWidget *w, gpointer data)
 {
-	GnomeCalc *gc = g_object_get_data(G_OBJECT(w), "set_data");
+	GnomeCalc *gc = gtk_object_get_user_data(GTK_OBJECT(w));
 
 	g_return_if_fail(gc!=NULL);
 
@@ -1078,7 +1033,7 @@ add_parenth(GtkWidget *w, gpointer data)
 static void
 sub_parenth(GtkWidget *w, gpointer data)
 {
-	GnomeCalc *gc = g_object_get_data(G_OBJECT(w), "set_data");
+	GnomeCalc *gc = gtk_object_get_user_data(GTK_OBJECT(w));
 	g_return_if_fail(gc!=NULL);
 
 	if(gc->_priv->error)
@@ -1106,44 +1061,6 @@ sub_parenth(GtkWidget *w, gpointer data)
 	unselect_invert(gc);
 }
 
-static double
-sin_helper (double value)
-{
-	double ret = sin (value);
-	
-	if (fabs (ret) <= fabs (sin (M_PI))) 
-		return 0.0;
-	else
-		return ret;
-}
-
-static double
-cos_helper (double value)
-{
-	double ret = cos (value);
-	if (fabs (ret) <= fabs (cos (M_PI_2)))
-		return 0.0;
-	else
-		return ret;
-}
-
-static double
-tan_helper (double value)
-{
-	double ret = tan (value);
-	double temp1, temp2;
-
-	if (fabs (ret) >= fabs (tan(3 * M_PI_2))) {
-		errno=ERANGE;
-		return 0.0;
-	}
-	else if (fabs (ret) <= fabs (tan(M_PI))) {
-		return 0.0;
-	}
-	else
-		return ret;
-}
-
 static const CalculatorButton buttons[8][5] = {
 	{
 		{N_("1/x"),  (GtkSignalFunc)simple_func, c_inv,  NULL,   FALSE, {0}, N_("Inverse"), NULL },
@@ -1152,12 +1069,11 @@ static const CalculatorButton buttons[8][5] = {
 		{N_("CE/C"), (GtkSignalFunc)clear_calc,  NULL,   NULL,   FALSE, {GDK_Clear,GDK_Delete,0}, N_("Clear"), NULL },
 		{N_("AC"),   (GtkSignalFunc)reset_calc,  NULL,   NULL,   FALSE, {'a','A', GDK_Escape, 0}, N_("Reset"), NULL }
 	},{
-		{N_("INV"),  NULL,                       NULL,   NULL,   FALSE, {'i','I',0}, N_("Inverse trigonometry/log function"), NULL }, /*inverse button*/
-		{N_("sin"),  (GtkSignalFunc)simple_func, sin_helper, asin, TRUE,{'s','S',0}, N_("Sine"), NULL },
-		{N_("cos"),  (GtkSignalFunc)simple_func, cos_helper, acos, TRUE,{'c','C',0}, N_("Cosine"), NULL },
-		{N_("tan"),  (GtkSignalFunc)simple_func, tan_helper,    atan,   TRUE,  {'t','T',0}, N_("Tangent"), NULL },
-		/* Ugly hack so that window won't resize when selecting GRAD - there should be a better fix that this */
-		{N_(" DEG  "),  (GtkSignalFunc)drg_toggle,  NULL,   NULL,   FALSE, {'d','D',0}, N_("Switch degrees / radians / grad"), NULL }
+		{N_("INV"),  NULL,                       NULL,   NULL,   FALSE, {'i','I',0}, N_("Shift"), NULL }, /*inverse button*/
+		{N_("sin"),  (GtkSignalFunc)simple_func, sin,    asin,   TRUE,  {'s','S',0}, N_("Sine"), NULL },
+		{N_("cos"),  (GtkSignalFunc)simple_func, cos,    acos,   TRUE,  {'c','C',0}, N_("Cosine"), NULL },
+		{N_("tan"),  (GtkSignalFunc)simple_func, tan,    atan,   TRUE,  {'t','T',0}, N_("Tangent"), NULL },
+		{N_("DEG"),  (GtkSignalFunc)drg_toggle,  NULL,   NULL,   FALSE, {'d','D',0}, N_("Switch degrees / radians / grad"), NULL }
 	},{
 		{N_("e"),    (GtkSignalFunc)set_e,       NULL,   NULL,   FALSE, {'e','E',0}, N_("Base of Natural Logarithm"), NULL },
 		{N_("EE"),   (GtkSignalFunc)add_digit,   "e+",   NULL,   FALSE, {0}, N_("Add digit"), NULL },
@@ -1171,25 +1087,25 @@ static const CalculatorButton buttons[8][5] = {
 		{N_(")"),    (GtkSignalFunc)sub_parenth, NULL,   NULL,   FALSE, {')',0}, N_("Closing Parenthesis"), NULL },
 		{N_("/"),    (GtkSignalFunc)math_func,   c_div,  NULL,   FALSE, {'/',GDK_KP_Divide,0}, N_("Divide by"), NULL }
 	},{
-		{N_("STO"),  (GtkSignalFunc)store_m,     NULL,   NULL,   FALSE, {0}, N_("Store the value in the\ndisplay field in memory"), NULL },
+		{N_("STO"),  (GtkSignalFunc)store_m,     NULL,   NULL,   FALSE, {0}, N_("Store"), NULL },
 		{N_("7"),    (GtkSignalFunc)add_digit,   NULL,   NULL,   FALSE, {'7',GDK_KP_7,GDK_KP_Home,0}, NULL, NULL },
 		{N_("8"),    (GtkSignalFunc)add_digit,   NULL,   NULL,   FALSE, {'8',GDK_KP_8,GDK_KP_Up,0}, NULL, NULL },
 		{N_("9"),    (GtkSignalFunc)add_digit,   NULL,   NULL,   FALSE, {'9',GDK_KP_9,GDK_KP_Page_Up,0}, NULL, NULL },
 		{N_("*"),    (GtkSignalFunc)math_func,   c_mul,  NULL,   FALSE, {'*',GDK_KP_Multiply,0}, N_("Multiply by"), NULL }
 	},{
-		{N_("RCL"),  (GtkSignalFunc)recall_m,    NULL,   NULL,   FALSE, {0}, N_("Display the value in memory\nin the display field"), NULL },
+		{N_("RCL"),  (GtkSignalFunc)recall_m,    NULL,   NULL,   FALSE, {0}, N_("Recall"), NULL },
 		{N_("4"),    (GtkSignalFunc)add_digit,   NULL,   NULL,   FALSE, {'4',GDK_KP_4,GDK_KP_Left,0}, NULL, NULL },
 		{N_("5"),    (GtkSignalFunc)add_digit,   NULL,   NULL,   FALSE, {'5',GDK_KP_5,GDK_KP_Begin,0}, NULL, NULL },
 		{N_("6"),    (GtkSignalFunc)add_digit,   NULL,   NULL,   FALSE, {'6',GDK_KP_6,GDK_KP_Right,0}, NULL, NULL },
 		{N_("-"),    (GtkSignalFunc)math_func,   c_sub,  NULL,   FALSE, {'-',GDK_KP_Subtract,0}, N_("Subtract"), NULL }
 	},{
-		{N_("SUM"),  (GtkSignalFunc)sum_m,       NULL,   NULL,   FALSE, {0}, N_("Add the value in the display\nfield to the value in memory"), NULL },
+		{N_("SUM"),  (GtkSignalFunc)sum_m,       NULL,   NULL,   FALSE, {0}, N_("Sum"), NULL },
 		{N_("1"),    (GtkSignalFunc)add_digit,   NULL,   NULL,   FALSE, {'1',GDK_KP_1,GDK_KP_End,0}, NULL, NULL },
 		{N_("2"),    (GtkSignalFunc)add_digit,   NULL,   NULL,   FALSE, {'2',GDK_KP_2,GDK_KP_Down,0}, NULL, NULL },
 		{N_("3"),    (GtkSignalFunc)add_digit,   NULL,   NULL,   FALSE, {'3',GDK_KP_3,GDK_KP_Page_Down,0}, NULL, NULL },
 		{N_("+"),    (GtkSignalFunc)math_func,   c_add,  NULL,   FALSE, {'+',GDK_KP_Add,0}, N_("Add"), NULL }
 	},{
-		{N_("EXC"),  (GtkSignalFunc)exchange_m,  NULL,   NULL,   FALSE, {0}, N_("Exchange the values in the\ndisplay field and memory"), NULL },
+		{N_("EXC"),  (GtkSignalFunc)exchange_m,  NULL,   NULL,   FALSE, {0}, N_("Exchange"), NULL },
 		{N_("0"),    (GtkSignalFunc)add_digit,   NULL,   NULL,   FALSE, {'0',GDK_KP_0,GDK_KP_Insert,0}, NULL, NULL },
 		{N_("."),    (GtkSignalFunc)add_digit,   NULL,   NULL,   FALSE, {'.',GDK_KP_Decimal,',',GDK_KP_Delete,0}, N_("Decimal Point"), NULL },
 		{N_("+/-"),  (GtkSignalFunc)negate_val,  c_neg,  NULL,   FALSE, {0}, N_("Change sign"), NULL },
@@ -1212,20 +1128,13 @@ create_button(GnomeCalc *gc, GtkWidget *table, int x, int y)
 		gc->_priv->invert_button = w;
 		gtk_signal_connect (GTK_OBJECT (w), "toggled",
 				    GTK_SIGNAL_FUNC(invert_toggle), gc);
-	} 
-	else if (strcmp (but->name, "e") == 0) {
-		w = gtk_button_new_with_label (_(but->name));
-		gtk_signal_connect (GTK_OBJECT (w), "button_press_event",
-				    but->signal_func,
-				    (gpointer) but);
-	}
-	else {
+	} else {
 		w = gtk_button_new_with_label(_(but->name));
 		gtk_signal_connect(GTK_OBJECT(w), "clicked",
 				   but->signal_func,
 				   (gpointer) but);
 	}
-	
+
 	for(i=0;but->keys[i]!=0;i++) {
 		gtk_widget_add_accelerator(w, "clicked",
 					   gc->_priv->accel,
@@ -1244,10 +1153,10 @@ create_button(GnomeCalc *gc, GtkWidget *table, int x, int y)
 	}
 
 	if (but->tooltip != NULL) {
-		gtk_tooltips_set_tip(GTK_TOOLTIPS(gc->_priv->tooltips), w, _(but->tooltip), but->tooltip_private);
+		gtk_tooltips_set_tip(GTK_TOOLTIPS(gc->_priv->tooltips), w, but->tooltip, but->tooltip_private);
 	}
 
-	g_object_set_data(G_OBJECT(w), "set_data", gc);
+	gtk_object_set_user_data(GTK_OBJECT(w),gc);
 	gtk_widget_show(w);
 	gtk_table_attach(GTK_TABLE(table), w,
 			 x, x+1, y, y+1,
@@ -1263,30 +1172,26 @@ create_button(GnomeCalc *gc, GtkWidget *table, int x, int y)
 static void
 gnome_calc_instance_init (GnomeCalc *gc)
 {
-	GtkWidget *hbox, *event;
 	gint x,y;
 	GtkWidget *table;
-	GdkColor color;
-	
+	PangoFontDescription *pdesc;
+
 	gc->_priv = g_new0(GnomeCalcPrivate, 1);
-	
-	event = gtk_event_box_new ();
-	gtk_widget_show (event);
-	gdk_color_parse ("#000000", &color);
-	gtk_widget_modify_bg (event, GTK_STATE_NORMAL, &color); 
-	gtk_box_pack_start (GTK_BOX (gc), event, FALSE, FALSE, 0);
-	gtk_container_set_border_width (GTK_CONTAINER (event), 1);
-	
-	hbox = gtk_hbox_new (FALSE, 0);
-	gtk_widget_show (hbox);
-	gtk_container_add (GTK_CONTAINER (event), hbox);
-	
-	gc->_priv->text_display = gtk_label_new (NULL);
-	gtk_label_set_selectable (GTK_LABEL (gc->_priv->text_display), TRUE);
-	/*gtk_label_set_justify (GTK_LABEL (gc->_priv->text_display), GTK_JUSTIFY_RIGHT);*/
+
+	gc->_priv->text_display = gtk_entry_new ();
+	gtk_editable_set_editable (GTK_EDITABLE (gc->_priv->text_display), FALSE);
+
+	gtk_box_pack_start (GTK_BOX (gc), gc->_priv->text_display, FALSE, FALSE, 0);
+	gtk_widget_set_direction (gc->_priv->text_display, GTK_TEXT_DIR_RTL);
+
+	pdesc = pango_font_description_from_string ("Helvetica 24");
+	if (pdesc != NULL) {
+		gtk_widget_modify_font (gc->_priv->text_display, pdesc);
+		pango_font_description_free (pdesc);
+	}
+
 	gtk_widget_show (gc->_priv->text_display);
-	gtk_box_pack_end (GTK_BOX (hbox), gc->_priv->text_display, FALSE, TRUE, 0);	
-	
+
 	gc->_priv->stack = NULL;
 	gc->_priv->result = 0;
 	strcpy(gc->_priv->result_string," 0");
@@ -1300,18 +1205,15 @@ gnome_calc_instance_init (GnomeCalc *gc)
 	table = gtk_table_new(8,5,TRUE);
 	gtk_widget_show(table);
 
-	gtk_box_pack_start(GTK_BOX(gc),table,TRUE,TRUE,0);
+	gtk_box_pack_end(GTK_BOX(gc),table,TRUE,TRUE,0);
 
 	for(x=0;x<5;x++) {
 		for(y=0;y<8;y++) {
 			create_button(gc, table, x, y);
 		}
-	}	
-	
+	}
 	gtk_tooltips_enable (gc->_priv->tooltips);
-
-        set_display (gc);
-	
+	gtk_entry_set_text (GTK_ENTRY (gc->_priv->text_display), gc->_priv->result_string);
 }
 
 
@@ -1329,7 +1231,7 @@ gnome_calc_new (void)
 {
 	GnomeCalc *gcalculator;
 
-	gcalculator = g_object_new (gnome_calc_get_type (), NULL);
+	gcalculator = gtk_type_new (gnome_calc_get_type ());
 
 	return GTK_WIDGET (gcalculator);
 }
@@ -1439,7 +1341,7 @@ gnome_calc_get_result_string(GnomeCalc *gc)
 static void
 backspace_cb (GtkWidget *w, gpointer data)
 {
-	GnomeCalc *gc = g_object_get_data(G_OBJECT(w), "set_data");
+	GnomeCalc *gc = gtk_object_get_user_data(GTK_OBJECT(w));
 	char *old_locale;
 	gint length;
 
@@ -1478,9 +1380,9 @@ backspace_cb (GtkWidget *w, gpointer data)
 		if (stack->type == CALCULATOR_NUMBER)
 			stack->d.number = gc->_priv->result;
 	}
+	
+	gtk_entry_set_text (GTK_ENTRY (gc->_priv->text_display), gc->_priv->result_string);
 
-	set_display (gc);
- 	
 	/* make sure get values in a consistent manner */
 	old_locale = g_strdup (setlocale (LC_NUMERIC, NULL));
 	setlocale (LC_NUMERIC, "C");
@@ -1553,7 +1455,7 @@ gnome_calc_bind_extra_keys (GnomeCalc *gc,
 	g_return_if_fail (GNOME_IS_CALC (gc));
 	g_return_if_fail (GTK_IS_WIDGET (widget));
 
-	g_object_set_data (G_OBJECT (widget), "set_data", gc);
+	gtk_object_set_user_data (GTK_OBJECT (widget), gc);
 	
 	gtk_signal_connect (GTK_OBJECT (widget), "event",
 			    GTK_SIGNAL_FUNC (event_cb), gc);
